=========
delegates
=========


.. automodule:: camelot.view.controls.delegates
   :members:

.. toctree::

   booldelegate.rst
   chartdelegate.rst
   codedelegate.rst
   colordelegate.rst
   coloredfloatdelegate.rst
   comboboxdelegate.rst
   currencydelegate.rst
   customdelegate.rst
   datedelegate.rst
   datetimedelegate.rst
   delegatemanager.rst
   enumerationdelegate.rst
   filedelegate.rst
   floatdelegate.rst
   imagedelegate.rst
   integerdelegate.rst
   intervalsdelegate.rst
   labeldelegate.rst
   languagedelegate.rst
   localfiledelegate.rst
   many2onedelegate.rst
   manytomanydelegate.rst
   manytoonechoicesdelegate.rst
   monthsdelegate.rst
   notedelegate.rst
   one2manydelegate.rst
   plaintextdelegate.rst
   richtextdelegate.rst
   smileydelegate.rst
   stardelegate.rst
   texteditdelegate.rst
   timedelegate.rst
   virtualaddressdelegate.rst
